@@ -1,10 +1,14 @@
 from amazon_web_services_helpers.document_store import AwsHelper
 from amazon_web_services_helpers.document_store import DocumentStore
+from amazon_web_services_helpers.dynamo_db_helper import DynamoDbHelper
+from amazon_web_services_helpers.file_helper import FileHelper
 from amazon_web_services_helpers.s3_helper import S3Helper
 
 __all__ = (
     '__version__',
     'AwsHelper',
     'DocumentStore',
+    'DynamoDbHelper',
+    'FileHelper',
     'S3Helper'
 )
